/*
 * gtktube: a gtk frontend for freetv like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#ifndef __FREETV_SEARCH_H
#define __FREETV_SEARCH_H


#include "video.h"

enum freetv_xml_state
{
  FREETV_XML_STATE_UNKNOWN = 0,
  FREETV_XML_STATE_IN_FEED,
  FREETV_XML_STATE_IN_ENTRY,
  FREETV_XML_STATE_IN_ENTRY_AUTHOR,
  FREETV_XML_STATE_IN_ENTRY_AUTHOR_NAME,
  FREETV_XML_STATE_IN_ENTRY_PUBLISHED,
  FREETV_XML_STATE_IN_ENTRY_MEDIA_GROUP,
  FREETV_XML_STATE_IN_ENTRY_MEDIA_GROUP_TITLE,
  FREETV_XML_STATE_IN_ENTRY_MEDIA_GROUP_DESCRIPTION,
};


G_BEGIN_DECLS

#define FREETV_SEARCH_TYPE             (freetv_search_get_type ())
#define FREETV_SEARCH(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), FREETV_SEARCH_TYPE, FreeTvSearch))
#define FREETV_SEARCH_CLASS(obj)       (G_TYPE_CHECK_CLASS_CAST ((obj), FREETV_SEARCH, FreeTvSearchClass))
#define FREETV_SEARCH_GET_CLASS        (G_TYPE_INSTANCE_GET_CLASS ((obj), FREETV_SEARCH_TYPE, FreeTvSearchClass))

typedef struct _freetv_search          FreeTvSearch;
typedef struct _freetv_search_class    FreeTvSearchClass;

struct _freetv_search
{
  GObject parent_instance;

  /* private */
  GList *videos;

  /* network session */
  SoupSession *async_http_session;
  SoupMessage *msg;

  int current_url_index;
  int retry_for_this_url;

  /* result */
  int http_return_code;
  GError *gerror;

  /* XML parser state */
#if ENABLE_DEBUG
  int xml_indent;
#endif
  enum freetv_xml_state xml_state;
  Video *current_video;
};

struct _freetv_search_class
{
  GObjectClass parent_class;

  /* private */
};


GType freetv_search_get_type(void) G_GNUC_CONST;


FreeTvSearch *freetv_search_new(void);

gboolean freetv_search_load_playlist(FreeTvSearch *search);

void freetv_search_set_http_session(FreeTvSearch *search, SoupSession *http_session);

GList *freetv_search_get_results(FreeTvSearch *search);

G_END_DECLS

#endif

