/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */
#include <config.h>


#include <gtk/gtk.h>
#include <glib/gi18n.h>

#include "gtk_utils.h"
#include "utils.h"



/**
 *
 *
 */
GdkPixbuf *
gtk_utils_get_pixbuf_from_icon_name(const char *icon_name, int icon_size)
{
  GdkPixbuf *pixbuf;
  GtkIconTheme *theme = gtk_icon_theme_get_default();
  char icon_filepath[PATH_MAX];

  trace("Load icon %s in %dx%d\n", icon_name, icon_size, icon_size);

  if (icon_name == NULL)
    goto error_load_default_icon;

  if (icon_name[0] == '/')
   {
     pixbuf = gdk_pixbuf_new_from_file_at_scale(icon_name, icon_size, -1, TRUE, NULL);
     if (pixbuf == NULL)
       goto error_load_default_icon;
     return pixbuf;
   }

  /* Try to find the icon using gtk library */
  pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), icon_name, icon_size, GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
  if (pixbuf)
    return pixbuf;

  snprintf(icon_filepath, sizeof(icon_filepath), "/usr/share/pixmaps/%s", icon_name);
  pixbuf = gdk_pixbuf_new_from_file_at_scale(icon_filepath, icon_size, -1, TRUE, NULL);
  if (pixbuf)
    return pixbuf;

  snprintf(icon_filepath, sizeof(icon_filepath), DATADIR"/gtktube/%s", icon_name);
  pixbuf = gdk_pixbuf_new_from_file_at_scale(icon_filepath, icon_size, -1, TRUE, NULL);
  if (pixbuf)
    return pixbuf;

#if 0
  snprintf(icon_filepath, sizeof(icon_filepath), DATADIR"/icons/hicolor/48x48/apps/%s.png", icon_name);
  pixbuf = gdk_pixbuf_new_from_file_at_scale(icon_filepath, icon_size, -1, TRUE, NULL);
  if (pixbuf)
    return pixbuf;
#endif

error_load_default_icon:
  return gtk_icon_theme_load_icon(theme, "gtk-dialog-question", icon_size, GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
}


GdkPixbuf *
gtk_utils_get_pixbuf_from_data(gconstpointer data, guint datalen, GError **gerror)
{
  GdkPixbufLoader *loader;
  GdkPixbuf       *pixbuf;

  if (datalen == 0)
    return NULL;

  loader = gdk_pixbuf_loader_new ();

  if (gdk_pixbuf_loader_write(loader, data, datalen, gerror) == FALSE)
   {
     trace("gdk_pixbuf_loader_write() failed: %s\n", gerror?(*gerror)->message:"");
     gdk_pixbuf_loader_close(loader, NULL);
     g_object_unref(loader);
     return NULL;
   }

  if (gdk_pixbuf_loader_close(loader, gerror) == FALSE)
   {
     trace("gdk_pixbuf_loader_close() failed: %s\n", gerror?(*gerror)->message:"");
     g_object_unref(loader);
     return NULL;
   }

  pixbuf = gdk_pixbuf_loader_get_pixbuf(loader);
  if (pixbuf == NULL)
   {
     g_set_error(gerror, GDK_PIXBUF_ERROR, GDK_PIXBUF_ERROR_FAILED, _("Failed to load image: reason not known, probably a corrupt image file"));
     g_object_unref(G_OBJECT(loader));
     return NULL;
   }

  g_object_ref(pixbuf);
  g_object_unref(G_OBJECT(loader));
  return pixbuf;
}

/*
 * Display an error dialog box
 *
 * @param parent the root window (can be NULL)
 * @param string the string that are displayed in front of the message
 */
void
gtk_popup_dialog_error(GtkWidget *parent, const gchar *string)
{
  GtkWidget *error_dialog;

  error_dialog = gtk_message_dialog_new(parent ? GTK_WINDOW(parent) : NULL,
      					GTK_DIALOG_MODAL,
					GTK_MESSAGE_ERROR,
					GTK_BUTTONS_CLOSE,
					string);

  gtk_window_set_title(GTK_WINDOW(error_dialog), _("Easynetwork Error"));
  gtk_window_set_icon_name(GTK_WINDOW(error_dialog), "preferences-system-network");
  gtk_dialog_run(GTK_DIALOG(error_dialog));

  gtk_widget_destroy (error_dialog);
}

/*
 *
 *
 */
gboolean
gtk_combo_null_text_to_separator(GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
{
  gchar *text;
  gboolean result = FALSE;

  gtk_tree_model_get(model, iter, 0, &text, -1);

  if (text && *text == '\0')
    result = TRUE;

  g_free(text);

  return result;
}

















