/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#ifndef __GTKTUBE__H
#define __GTKTUBE__H


#include <gtk/gtk.h>
#include <libsoup/soup.h>
#include <gst/gst.h>

#include "video.h"
#include "video_view.h"
#include "gtktube_search.h"
#include "youtube_suggest.h"
#include "youtube_video.h"
#include "gtktube_plugin.h"

struct gtktube_private
{
  /* UI */
  GtkUIManager *ui;
  GtkWidget *main_window;
  GtkWidget *notebook;
  GtkWidget *statusbar;

  GtkWidget *progress_bar;

  GtkWidget *play_pause_image;

  GtkWidget *search_button;
  GtkWidget *search_entry;
  GtkEntryCompletion *search_completion;
  GtkListStore *suggests_store; /* The store that will contains suggestion for a search */

  GtkWidget *videos_box; /* The container that contains all infos (preview, star, author, ...) for video */


  /* The drawing area widget that display the video */
  VideoView *video_widget;
  GstState   video_state;

  /* Network */
  SoupSession *async_http_session;

  /* Main view */
  struct gtktube_search_plugin *search_plugin;

  /* Search Object */
  //YoutubeSearch *youtube;
  YoutubeSuggest *search_suggest;

  /* Previous result from a search */
  GList *videos;
  Video *current_video_selected;

  /* Timers */
  gint update_timer_id; /* The timer that update the progress bar while a video is playing */



};


/* Note: Do not change this constant if you don't change the order into gtktube_create_main_window() */
#define INDEX_PAGE_SEARCH  0
#define INDEX_PAGE_VIEW    1
#define INDEX_PAGE_MAX      (INDEX_PAGE_VIEW+1)


extern int opt_no_video;

void gtktube_show_page(struct gtktube_private *priv, guint page_number);

#endif

