/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#ifndef __GTKTUBE_SEARCH__H
#define __GTKTUBE_SEARCH__H

#include <glib.h>
#include <libsoup/soup.h>

#include "gtktube_plugin.h"

typedef void     (*SearchPluginSetHttpSessionCallback)(gpointer, SoupSession *);
typedef void     (*SearchPluginProgressStatusCallback)(guint64, guint64, gpointer user_data);
typedef void     (*SearchPluginSearchFinishedCallback)(GList *videos, gpointer user_data);
typedef gboolean (*SearchPluginSearchForCallback)(gpointer, const char *);
typedef gboolean (*SearchPluginLoadPlaylistCallback)(gpointer);


struct gtktube_search_plugin
{
  char *name;
  char *description;

  enum gtktube_plugin_type type;

  char *logo;

  gboolean have_suggest_completion;
  gboolean have_search;

  /* private API */
  gpointer priv;

  SearchPluginSearchFinishedCallback search_finished_cb;
  gpointer search_finished_cb_priv_data;

  SearchPluginProgressStatusCallback progress_status_cb;
  gpointer progress_status_cb_priv_data;

  SearchPluginSetHttpSessionCallback set_http_session;
  SearchPluginSearchForCallback      search_for;
  SearchPluginLoadPlaylistCallback   load_playlist;
};

gboolean gtktube_search_plugin_register(struct gtktube_search_plugin *plugin);

void gtktube_search_plugin_unregister(struct gtktube_search_plugin *plugin);



struct gtktube_search_plugin *gtktube_search_plugin_get_first(void);

struct gtktube_search_plugin *gtktube_search_plugin_find_by_name(const char *name);

GSList *gtktube_search_plugin_get_names(void);


gboolean gtktube_search_plugin_start_new_search(struct gtktube_search_plugin *plugin, const char *text);

gboolean gtktube_search_plugin_load_playlist(struct gtktube_search_plugin *plugin);

void gtktube_search_plugin_set_search_finished_cb(struct gtktube_search_plugin      *plugin,
   						  SearchPluginSearchFinishedCallback callback,
						  gpointer                           private_data);

void gtktube_search_plugin_set_progress_status_cb(struct gtktube_search_plugin      *plugin,
   						  SearchPluginProgressStatusCallback callback,
						  gpointer                           private_data);

void gtktube_search_plugin_set_http_session(struct gtktube_search_plugin *plugin,
   					    SoupSession                  *http_session);

#endif

