/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */


#include <config.h>

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <locale.h>
#include <glib/gi18n.h>
#include <glib.h>

#include "gtktube_plugin.h"
#include "utils.h"


static GSList *plugins = NULL;

struct gtktube_plugin_internal
{
  void *handle;
  gboolean active;
  struct gtktube_plugin *desc;
};



static gboolean
gtktube_add_plugin(void *handle, struct gtktube_plugin *plug)
{
  struct gtktube_plugin_internal *plugin;

  if (plug->init == NULL)
    return FALSE;

  /* TODO: Check version */

  plugin = g_try_new0(struct gtktube_plugin_internal, 1);
  if (plugin == NULL)
    return FALSE;

  plugin->handle = handle;
  plugin->active = FALSE;
  plugin->desc = plug;

  plugins = g_slist_prepend(plugins, plugin);

  return TRUE;
}

extern struct gtktube_plugin __gtktube_builtin_youtube;
extern struct gtktube_plugin __gtktube_builtin_freetv;

static struct gtktube_plugin *__builtin_plugins[] =
{
  &__gtktube_builtin_freetv,
  &__gtktube_builtin_youtube,
};


gboolean
gtktube_plugin_init(void)
{
  GSList *list;
  unsigned int i;

  trace("\n");

  for (i=0; i<G_N_ELEMENTS(__builtin_plugins); i++)
   {
     gtktube_add_plugin(NULL, __builtin_plugins[i]);
   }

  /* TODO: Load module from plugin dir */

  for (list=plugins; list; list=list->next)
   {
     struct gtktube_plugin_internal *plugin = list->data;

     if (plugin->desc->init() < 0)
       continue;

     plugin->active = TRUE;
   }


  return TRUE;
}


void
gtktube_plugin_exit(void)
{



}





