/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */


#include <config.h>

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <locale.h>
#include <glib/gi18n.h>
#include <glib.h>

#include "gtktube_plugin.h"
#include "gtktube_search.h"

#include "utils.h"

static GSList *search_plugins_list = NULL;









/*
 *
 *
 * Plugin Public API
 *
 *
 */



gboolean
gtktube_search_plugin_register(struct gtktube_search_plugin *plugin)
{
  trace("plugin=%p/%s\n", plugin, plugin?plugin->name:"(null)");

  search_plugins_list = g_slist_prepend(search_plugins_list, plugin);

  return TRUE;
}


void
gtktube_search_plugin_unregister(struct gtktube_search_plugin *plugin)
{
  search_plugins_list = g_slist_remove(search_plugins_list, plugin);

}


/*
 *
 *
 * Public API
 *
 *
 */


struct gtktube_search_plugin *
gtktube_search_plugin_get_first(void)
{
  if (search_plugins_list)
    return search_plugins_list->data;
  return NULL;
}

struct gtktube_search_plugin *
gtktube_search_plugin_find_by_name(const char *name)
{
  GSList *list;

  if (name == NULL)
    return NULL;

  for (list=search_plugins_list; list; list=list->next)
   {
     struct gtktube_search_plugin *plugin = list->data;
     if (strcmp(name, plugin->name) == 0)
       return plugin;
   }

  return NULL;
}

GSList *
gtktube_search_plugin_get_names(void)
{
  GSList *list, *names = NULL;

  for (list=search_plugins_list; list; list=list->next)
   {
     struct gtktube_search_plugin *plugin = list->data;
     names = g_slist_prepend(names, g_strdup(plugin->name));
   }

  return names;
}


gboolean
gtktube_search_plugin_start_new_search(struct gtktube_search_plugin *plugin, const char *text)
{
  if (plugin->search_for)
    return plugin->search_for(plugin->priv, text);
  return FALSE;
}

void
gtktube_search_plugin_set_search_finished_cb(struct gtktube_search_plugin *plugin,
   					     SearchPluginSearchFinishedCallback callback,
					     gpointer private_data)
{
  plugin->search_finished_cb = callback;
  plugin->search_finished_cb_priv_data = private_data;
}

void
gtktube_search_plugin_set_progress_status_cb(struct gtktube_search_plugin *plugin,
   					     SearchPluginProgressStatusCallback callback,
					     gpointer private_data)
{
  plugin->progress_status_cb = callback;
  plugin->progress_status_cb_priv_data = private_data;
}

void
gtktube_search_plugin_set_http_session(struct gtktube_search_plugin *plugin, SoupSession *http_session)
{
  plugin->set_http_session(plugin->priv, http_session);
}

gboolean
gtktube_search_plugin_load_playlist(struct gtktube_search_plugin *plugin)
{
  g_return_val_if_fail(plugin != NULL, FALSE);
  g_return_val_if_fail(plugin->load_playlist != NULL, FALSE);

  return plugin->load_playlist(plugin->priv);
}






