/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#ifndef __VIDEO_H
#define __VIDEO_H

typedef void (*VideoGotUrlFunc)(char *url, GList *video_sizes, gpointer user_data);


G_BEGIN_DECLS

#define VIDEO_TYPE             (video_get_type ())
#define VIDEO(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIDEO_TYPE, Video))
#define VIDEO_CLASS(obj)       (G_TYPE_CHECK_CLASS_CAST ((obj), VIDEO, VideoClass))
#define VIDEO_GET_CLASS        (G_TYPE_INSTANCE_GET_CLASS ((obj), VIDEO_TYPE, VideoClass))

typedef struct _video          Video;
typedef struct _video_class    VideoClass;

struct _video
{
  GObject parent_instance;

  /* private */
  char *webpage;
  char *author_name;
  char *title;
  char *description;
  time_t date_published;
  int   duration;

  /* statistics */
  int   favorites;
  int   views;

  /* ratings */
  double avg_rating;
  int    min_rating;
  int    max_rating;
  int    num_votes;

  /* thumbnail */
  GList *thumbnails;
  GList *next_thumbnail;
  GtkWidget *preview_image;
  gboolean thumbnail_is_loading;
  GtkWidget *evbox;

  /* big preview */
  GList *previews;

  /* state */
  gboolean is_selected;


  /* Video */
  GList *sizes;
};

struct _video_class
{
  GObjectClass parent_class;

  /* private */
};


GType video_get_type(void) G_GNUC_CONST;




Video *video_new(void);

void video_set_webpage(Video *video, const char *href);

void video_set_author_name(Video *video, const char *text, gsize text_len);

void video_set_title(Video *video, const char *text, gsize text_len);

void video_set_description(Video *video, const char *text, gsize text_len);

void video_set_duration(Video *video, int duration_in_sec);

void video_set_published_date(Video *video, int since_epoch);

void video_set_statistics(Video *video, int views, int favorites);

void video_set_ratings(Video *video, gdouble avg, int min, int max, int num);

void video_set_state(Video *video, gboolean is_selected);

void video_add_thumbnail_uri(Video *video, const char *uri, int width, int height);

void video_add_content(Video *video, const char *uri, const char *type, guint format);

GtkWidget *video_create_widget(Video *video);

void video_load_thumbnails(Video *video, SoupSession *http_session);

void video_update_thumbnail(Video *video, SoupSession *http_session);

gboolean video_prepare_streaming(Video *video, SoupSession *http_session);



G_END_DECLS

#endif

