/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */
#include <config.h>

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <glib/gi18n.h>
#include <glib.h>
#include <gtk/gtk.h>

#include "gtktube.h"
#include "gtk_utils.h"
#include "video.h"
#include "video_thumbnail.h"
#include "utils.h"

enum
{
  SIGNAL_IMG_LOADED = 0,
  SIGNAL_LAST
};

static gint video_thumbnails_signals[SIGNAL_LAST];


/*
 *
 *
 *
 */
static void
video_thumbnail_load_finished(SoupSession *session, SoupMessage *msg, gpointer user_data)
{
  VideoThumbnail *thumbnail = user_data;
  GError *gerror = NULL;

  if (SOUP_STATUS_IS_TRANSPORT_ERROR(msg->status_code))
   {
     trace("download status code: %d (url=%s)\n", msg->status_code, thumbnail->uri);
     thumbnail->error = msg->status_code;
   } 
  else
   {
     thumbnail->error = 0;

     trace("%s: %d bytes downloaded\n", thumbnail->uri, (gsize)msg->response_body->length);

     thumbnail->pixbuf = gtk_utils_get_pixbuf_from_data(msg->response_body->data, msg->response_body->length, &gerror);
     if (thumbnail->pixbuf == NULL)
       thumbnail->error = 999;
   }

  /* Emit signal even if they are an error */
  g_signal_emit(thumbnail, video_thumbnails_signals[SIGNAL_IMG_LOADED], 0);
}


/*
 *
 *
 *
 */
void
video_thumbnail_load_with_session(VideoThumbnail *thumbnail, SoupSession *session)
{
  SoupMessage *msg;

  trace("url=%s\n", thumbnail->uri);

  thumbnail->error = -1;

  msg = soup_message_new("GET", thumbnail->uri);
  if (msg == NULL)
    return;

  soup_session_queue_message(session, msg, video_thumbnail_load_finished, thumbnail);
}


/*
 *
 *
 *
 */
VideoThumbnail *
video_thumbnail_new(const char *uri, int width, int height)
{
  VideoThumbnail *thumbnail = g_object_new(VIDEO_THUMBNAIL_TYPE, NULL);

  thumbnail->uri = g_strdup(uri);
  thumbnail->width = width;
  thumbnail->height = height;

  return thumbnail;
}






/***********************************************************************
 *
 *
 *
 *
 * GObject things
 *
 *
 *
 *
 **********************************************************************/
G_DEFINE_TYPE(VideoThumbnail, video_thumbnail, G_TYPE_OBJECT)

static void
video_thumbnail_dispose(GObject *object)
{
  VideoThumbnail *thumbnail = (VideoThumbnail *)(object);

  trace("\n");

  if (thumbnail->uri)
    g_free(thumbnail->uri);
  thumbnail->uri = NULL;

  G_OBJECT_CLASS (video_thumbnail_parent_class)->dispose(object);
}

static void
video_thumbnail_class_init(VideoThumbnailClass *klass)
{
  GObjectClass *gobject_class = G_OBJECT_CLASS(klass);

  gobject_class->dispose = video_thumbnail_dispose;

  video_thumbnails_signals[SIGNAL_IMG_LOADED] =
        g_signal_new("img-loaded",
                     G_TYPE_FROM_CLASS(gobject_class),
                     G_SIGNAL_RUN_LAST,
                     0,
                     NULL, NULL,
                     g_cclosure_marshal_VOID__VOID,
                     G_TYPE_NONE, 0);

}

static void
video_thumbnail_init(VideoThumbnail *search)
{
  trace("\n");

}




