/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#ifndef __VIDEO_VIEW_H
#define __VIDEO_VIEW_H

#include <gtk/gtk.h>
#include <gst/gst.h>

#include "video.h"

G_BEGIN_DECLS


#if 1
#define VIDEO_VIEW_WIDTH  480
#define VIDEO_VIEW_HEIGHT 360
#else
#define VIDEO_VIEW_WIDTH  640
#define VIDEO_VIEW_HEIGHT 380
#endif



#define VIDEO_VIEW_TYPE             (video_view_get_type ())
#define VIDEO_VIEW(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIDEO_VIEW_TYPE, VideoView))
#define VIDEO_VIEW_CLASS(obj)       (G_TYPE_CHECK_CLASS_CAST ((obj), VIDEO_VIEW, VideoViewClass))
#define VIDEO_VIEW_GET_CLASS        (G_TYPE_INSTANCE_GET_CLASS ((obj), VIDEO_VIEW_TYPE, VideoViewClass))

typedef struct _video_view          VideoView;
typedef struct _video_view_class    VideoViewClass;

struct _video_view
{
  GtkDrawingArea parent_instance;

  /* private */
  int width;
  int height;

  /* Gstreamer */
  GstElement *pipeline;
  GstElement *videosink;
  GstElement *playbin;

  /* Parent and information */
  Video *video;

  /* Capabilities */
  gboolean has_audio;
  gboolean has_video;

  gint     video_width;
  gint     video_height;
  gdouble  video_fps;

  gint     audio_nchannels;
  gint     audio_rate;
};

struct _video_view_class
{
  GtkDrawingAreaClass parent_class;

  /* private */
};


GType video_view_get_type(void) G_GNUC_CONST;

GtkWidget *video_view_new();

void video_view_set_video(VideoView *view, Video *video, SoupSession *session);

void video_view_play(VideoView *view);

void video_view_pause(VideoView *view);

void video_view_stop(VideoView *view);

void video_view_get_times(VideoView *view, gint64 *position, gint64 *duration);

G_END_DECLS

#endif



