/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#ifndef __YOUTUBE_SEARCH_H
#define __YOUTUBE_SEARCH_H


#include "video.h"

enum youtube_xml_state
{
  YOUTUBE_XML_STATE_UNKNOWN = 0,
  YOUTUBE_XML_STATE_IN_FEED,
  YOUTUBE_XML_STATE_IN_ENTRY,
  YOUTUBE_XML_STATE_IN_ENTRY_AUTHOR,
  YOUTUBE_XML_STATE_IN_ENTRY_AUTHOR_NAME,
  YOUTUBE_XML_STATE_IN_ENTRY_PUBLISHED,
  YOUTUBE_XML_STATE_IN_ENTRY_MEDIA_GROUP,
  YOUTUBE_XML_STATE_IN_ENTRY_MEDIA_GROUP_TITLE,
  YOUTUBE_XML_STATE_IN_ENTRY_MEDIA_GROUP_DESCRIPTION,
};


enum search_order
{
  SORT_BY_NEWEST = 0,
  SORT_BY_POPULARITY,
  SORT_BY_COUNT,
};

G_BEGIN_DECLS

#define YOUTUBE_SEARCH_TYPE             (youtube_search_get_type ())
#define YOUTUBE_SEARCH(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), YOUTUBE_SEARCH_TYPE, YoutubeSearch))
#define YOUTUBE_SEARCH_CLASS(obj)       (G_TYPE_CHECK_CLASS_CAST ((obj), YOUTUBE_SEARCH, YoutubeSearchClass))
#define YOUTUBE_SEARCH_GET_CLASS        (G_TYPE_INSTANCE_GET_CLASS ((obj), YOUTUBE_SEARCH_TYPE, YoutubeSearchClass))

typedef struct _youtube_search          YoutubeSearch;
typedef struct _youtube_search_class    YoutubeSearchClass;

struct _youtube_search
{
  GObject parent_instance;

  /* private */
  gint start_index;
  gint max_result;
  enum search_order search_order;

  GList *videos;

  /* network session */
  SoupSession *async_http_session;
  SoupMessage *msg;

  /* result */
  int http_return_code;
  GError *gerror;

  /* XML parser state */
#if ENABLE_DEBUG
  int xml_indent;
#endif
  enum youtube_xml_state xml_state;
  Video *current_video;

};

struct _youtube_search_class
{
  GObjectClass parent_class;

  /* private */
};


GType youtube_search_get_type(void) G_GNUC_CONST;


YoutubeSearch *youtube_search_new(void);

gboolean youtube_search_search_with_keywords(YoutubeSearch *search, const char *keywords);

void youtube_search_set_http_session(YoutubeSearch *search, SoupSession *http_session);

GList *youtube_search_get_results(YoutubeSearch *search);

G_END_DECLS

#endif

